@@ -1,5 +1,5 @@
 # This file is part of ReText
-# Copyright: 2012-2015 Dmitry Shachnev
+# Copyright: 2012-2021 Dmitry Shachnev
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@ class HtmlDialog(QDialog):
 		self.hl.docType = 'html'
 		verticalLayout.addWidget(self.textEdit)
 		buttonBox = QDialogButtonBox(self)
-		buttonBox.setStandardButtons(QDialogButtonBox.Close)
+		buttonBox.setStandardButtons(QDialogButtonBox.StandardButton.Close)
 		buttonBox.rejected.connect(self.close)
 		verticalLayout.addWidget(buttonBox)
 
@@ -50,7 +50,7 @@ class LocaleDialog(QDialog):
 		self.checkBox = QCheckBox(self.tr('Set as default'), self)
 		verticalLayout.addWidget(self.checkBox)
 		buttonBox = QDialogButtonBox(self)
-		buttonBox.setStandardButtons(QDialogButtonBox.Cancel | QDialogButtonBox.Ok)
+		buttonBox.setStandardButtons(QDialogButtonBox.StandardButton.Cancel | QDialogButtonBox.StandardButton.Ok)
 		verticalLayout.addWidget(buttonBox)
 		buttonBox.accepted.connect(self.accept)
 		buttonBox.rejected.connect(self.reject)
