@@ -1,7 +1,7 @@
 # vim: ts=8:sts=8:sw=8:noexpandtab
 #
 # This file is part of ReText
-# Copyright: 2015-2017 Dmitry Shachnev
+# Copyright: 2015-2021 Dmitry Shachnev
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from os.path import exists, splitext
+import time
 from markups import get_markup_for_file_name, find_markup_class_by_name
 from markups.common import MODULE_HOME_PAGE
 
@@ -31,8 +32,8 @@ except ImportError:
 	enchant = None
 
 from PyQt5.QtCore import pyqtSignal, Qt, QDir, QFile, QFileInfo, QPoint, QTextStream, QTimer, QUrl
-from PyQt5.QtGui import QTextCursor, QTextDocument
-from PyQt5.QtWidgets import QTextEdit, QSplitter
+from PyQt5.QtGui import QPalette, QTextCursor, QTextDocument
+from PyQt5.QtWidgets import QApplication, QTextEdit, QSplitter, QMessageBox
 
 try:
 	from ReText.webkitpreview import ReTextWebKitPreview
@@ -61,7 +62,7 @@ class ReTextTab(QSplitter):
 		return self._fileName
 
 	def __init__(self, parent, fileName, previewState=PreviewDisabled):
-		super(QSplitter, self).__init__(Qt.Horizontal, parent=parent)
+		super().__init__(Qt.Orientation.Horizontal, parent=parent)
 		self.p = parent
 		self._fileName = fileName
 		self.editBox = ReTextEdit(self)
@@ -72,6 +73,7 @@ class ReTextTab(QSplitter):
 		self.previewState = previewState
 		self.previewOutdated = False
 		self.conversionPending = False
+		self.cssFileExists = False
 
 		self.converterProcess = converterprocess.ConverterProcess()
 		self.converterProcess.conversionDone.connect(self.updatePreviewBox)
@@ -86,7 +88,7 @@ class ReTextTab(QSplitter):
 		self.editBox.textChanged.connect(self.triggerPreviewUpdate)
 		self.editBox.undoAvailable.connect(parent.actionUndo.setEnabled)
 		self.editBox.redoAvailable.connect(parent.actionRedo.setEnabled)
-		self.editBox.copyAvailable.connect(parent.actionCopy.setEnabled)
+		self.editBox.copyAvailable.connect(parent.enableCopy)
 
 		# Give both boxes a minimum size so the minimumSizeHint will be
 		# ignored when splitter.setSizes is called below
@@ -195,19 +197,38 @@ class ReTextTab(QSplitter):
 				errMsg = errMsg.replace('<a href="%s">', '').replace('</a>', '')
 			return '<p style="color: red">%s</p>' % errMsg
 		headers = ''
-		if includeStyleSheet:
+		if includeStyleSheet and self.p.ss is not None:
 			headers += '<style type="text/css">\n' + self.p.ss + '</style>\n'
+		elif includeStyleSheet:
+			style = 'td, th { border: 1px solid #c3c3c3; padding: 0 3px 0 3px; }\n'
+			style += 'table { border-collapse: collapse; }\n'
+			style += 'img { max-width: 100%; }\n'
+			# QTextDocument seems to use media=screen even for printing
+			if not isinstance(self.previewBox, QTextEdit) and not webenv:
+				# https://github.com/retext-project/retext/pull/187
+				palette = QApplication.palette()
+				fgColor = palette.color(QPalette.ColorRole.Text).name()
+				bgColor = palette.color(QPalette.ColorRole.Base).name()
+				linkColor = palette.color(QPalette.ColorRole.Link).name()
+				visitedLinkColor = palette.color(QPalette.ColorRole.LinkVisited).name()
+				style += ('@media screen {\n'
+				          f'  html {{ color: {fgColor}; background-color: {bgColor}; }}\n'
+				          f'  a, a * {{ color: {linkColor}; }}\n'
+				          f'  a:visited, a:visited * {{ color: {visitedLinkColor}; }}\n'
+				          '}\n')
+				# https://github.com/retext-project/retext/issues/408
+				style += '@media print { html { background-color: white; } }\n'
+			headers += '<style type="text/css">\n' + style + '</style>\n'
 		baseName = self.getBaseName()
-		cssFileName = baseName + '.css'
-		if QFile.exists(cssFileName):
-			headers += ('<link rel="stylesheet" type="text/css" href="%s">\n'
-			% cssFileName)
+		if self.cssFileExists:
+			headers += ('<link rel="stylesheet" type="text/css" href="%s.css">\n'
+			% baseName)
 		headers += ('<meta name="generator" content="ReText %s">\n' % app_version)
 		return converted.get_whole_html(
 			custom_headers=headers, include_stylesheet=includeStyleSheet,
 			fallback_title=baseName, webenv=webenv)
 
-	def getDocumentForExport(self, includeStyleSheet, webenv):
+	def getDocumentForExport(self, includeStyleSheet=True, webenv=False):
 		markupClass = self.getActiveMarkupClass()
 		if markupClass and markupClass.available():
 			exportMarkup = markupClass(filename=self._fileName)
@@ -234,19 +255,22 @@ class ReTextTab(QSplitter):
 		if isinstance(self.previewBox, QTextEdit):
 			scrollbar = self.previewBox.verticalScrollBar()
 			scrollbarValue = scrollbar.value()
-			distToBottom = scrollbar.maximum() - scrollbarValue
+			# If scrollbar was not on top, save its distance to bottom so that
+			# it will be restored in previewBox.updateScrollPosition() later.
+			if scrollbarValue:
+				self.previewBox.distToBottom = scrollbar.maximum() - scrollbarValue
+			else:
+				self.previewBox.distToBottom = None
 		try:
 			html = self.getHtmlFromConverted(self.converted)
 		except Exception:
 			return self.p.printError()
 		if isinstance(self.previewBox, QTextEdit):
+			self.previewBox.lastRenderTime = time.time()
 			self.previewBox.setHtml(html)
 			self.previewBox.document().setDefaultFont(globalSettings.font)
-			# If scrollbar was at bottom (and that was not the same as top),
-			# set it to bottom again
-			if scrollbarValue:
-				newValue = scrollbar.maximum() - distToBottom
-				scrollbar.setValue(newValue)
+			self.previewBox.updateScrollPosition(scrollbar.minimum(),
+			                                     scrollbar.maximum())
 		else:
 			self.previewBox.updateFontSettings()
 
@@ -263,6 +287,8 @@ class ReTextTab(QSplitter):
 
 	def triggerPreviewUpdate(self):
 		self.previewOutdated = True
+		if self.previewState == PreviewDisabled:
+			return
 
 		if not self.conversionPending:
 			self.conversionPending = True
@@ -274,8 +300,9 @@ class ReTextTab(QSplitter):
 			requested_extensions = ['ReText.mdx_posmap'] if globalSettings.syncScroll else []
 			self.converterProcess.start_conversion(self.getActiveMarkupClass().name,
 			                                       self.fileName,
-							       requested_extensions,
-							       self.editBox.toPlainText())
+			                                       requested_extensions,
+			                                       self.editBox.toPlainText(),
+			                                       QDir.currentPath())
 
 	def updateBoxesVisibility(self):
 		self.editBox.setVisible(self.previewState < PreviewNormal)
@@ -308,10 +335,11 @@ class ReTextTab(QSplitter):
 
 		result = chardet.detect(raw)
 		if result['confidence'] > 0.9:
-			if result['encoding'].lower() == 'ascii':
+			if result['encoding'].lower() in ('ascii', 'utf-8-sig'):
 				# UTF-8 files can be falsely detected as ASCII files if they
 				# don't contain non-ASCII characters in first 2048 bytes.
 				# We map ASCII to UTF-8 to avoid such situations.
+				# Also map UTF-8-SIG to UTF-8 because Qt does not understand it.
 				return 'utf-8'
 			return result['encoding']
 
@@ -327,7 +355,7 @@ class ReTextTab(QSplitter):
 		# TODO: why do we open the file twice: for detecting encoding
 		# and for actual read? Can we open it just once?
 		openfile = QFile(self._fileName)
-		openfile.open(QFile.ReadOnly)
+		openfile.open(QFile.OpenModeFlag.ReadOnly)
 		stream = QTextStream(openfile)
 		encoding = encoding or globalSettings.defaultCodec
 		if encoding:
@@ -339,31 +367,38 @@ class ReTextTab(QSplitter):
 		text = stream.readAll()
 		openfile.close()
 
-		self.editBox.setPlainText(text)
-		self.editBox.document().setModified(False)
-
 		if previousFileName != self._fileName:
 			self.updateActiveMarkupClass()
+
+		self.editBox.setPlainText(text)
+		self.editBox.document().setModified(False)
+		self.handleModificationChanged()
+
+		cssFileName = self.getBaseName() + '.css'
+		self.cssFileExists = QFile.exists(cssFileName)
+
+		if previousFileName != self._fileName:
 			self.fileNameChanged.emit()
 
 	def writeTextToFile(self, fileName=None):
 		# Just writes the text to file, without any changes to tab object
-		# Used directly for i.e. export extensions
+		# Used directly for e.g. export extensions
 
 		# Get text from the cursor to avoid tweaking special characters,
 		# see https://bugreports.qt.io/browse/QTBUG-57552 and
 		# https://github.com/retext-project/retext/issues/216
 		cursor = self.editBox.textCursor()
-		cursor.select(QTextCursor.Document)
+		cursor.select(QTextCursor.SelectionType.Document)
 		text = cursor.selectedText().replace('\u2029', '\n')
 
 		savefile = QFile(fileName or self._fileName)
-		result = savefile.open(QFile.WriteOnly)
+		result = savefile.open(QFile.OpenModeFlag.WriteOnly)
 		if result:
 			savestream = QTextStream(savefile)
 
 			# Save the file with original encoding
 			encoding = self.editBox.document().property("encoding")
+			encoding = encoding or globalSettings.defaultCodec
 			if encoding is not None:
 				savestream.setCodec(encoding)
 
@@ -386,12 +421,20 @@ class ReTextTab(QSplitter):
 
 		return result
 
+	def goToLine(self,line):
+		block = self.editBox.document().findBlockByLineNumber(line)
+		if block.isValid():
+			newCursor = QTextCursor(block)
+			self.editBox.setTextCursor(newCursor)
+
 	def find(self, text, flags, replaceText=None, wrap=False):
+		if self.previewState == PreviewNormal and replaceText is None:
+			return self.previewBox.findText(text, flags)
 		cursor = self.editBox.textCursor()
-		if wrap and flags & QTextDocument.FindBackward:
-			cursor.movePosition(QTextCursor.End)
+		if wrap and flags & QTextDocument.FindFlag.FindBackward:
+			cursor.movePosition(QTextCursor.MoveOperation.End)
 		elif wrap:
-			cursor.movePosition(QTextCursor.Start)
+			cursor.movePosition(QTextCursor.MoveOperation.Start)
 		if replaceText is not None and cursor.selectedText() == text:
 			newCursor = cursor
 		else:
@@ -399,9 +442,13 @@ class ReTextTab(QSplitter):
 		if not newCursor.isNull():
 			if replaceText is not None:
 				newCursor.insertText(replaceText)
-				newCursor.movePosition(QTextCursor.Left, QTextCursor.MoveAnchor, len(replaceText))
-				newCursor.movePosition(QTextCursor.Right, QTextCursor.KeepAnchor, len(replaceText))
+				newCursor.movePosition(QTextCursor.MoveOperation.Left, QTextCursor.MoveMode.MoveAnchor, len(replaceText))
+				newCursor.movePosition(QTextCursor.MoveOperation.Right, QTextCursor.MoveMode.KeepAnchor, len(replaceText))
 			self.editBox.setTextCursor(newCursor)
+			if self.editBox.cursorRect().bottom() >= self.editBox.height() - 3:
+				scrollValue = self.editBox.verticalScrollBar().value()
+				areaHeight = self.editBox.fontMetrics().height()
+				self.editBox.verticalScrollBar().setValue(scrollValue + areaHeight)
 			return True
 		if not wrap:
 			return self.find(text, flags, replaceText, True)
@@ -410,7 +457,7 @@ class ReTextTab(QSplitter):
 	def replaceAll(self, text, replaceText):
 		cursor = self.editBox.textCursor()
 		cursor.beginEditBlock()
-		cursor.movePosition(QTextCursor.Start)
+		cursor.movePosition(QTextCursor.MoveOperation.Start)
 		flags = QTextDocument.FindFlags()
 		cursor = lastCursor = self.editBox.document().find(text, cursor, flags)
 		while not cursor.isNull():
@@ -418,25 +465,68 @@ class ReTextTab(QSplitter):
 			lastCursor = cursor
 			cursor = self.editBox.document().find(text, cursor, flags)
 		if not lastCursor.isNull():
-			lastCursor.movePosition(QTextCursor.Left, QTextCursor.MoveAnchor, len(replaceText))
-			lastCursor.movePosition(QTextCursor.Right, QTextCursor.KeepAnchor, len(replaceText))
+			lastCursor.movePosition(QTextCursor.MoveOperation.Left, QTextCursor.MoveMode.MoveAnchor, len(replaceText))
+			lastCursor.movePosition(QTextCursor.MoveOperation.Right, QTextCursor.MoveMode.KeepAnchor, len(replaceText))
 			self.editBox.setTextCursor(lastCursor)
 		self.editBox.textCursor().endEditBlock()
 		return not lastCursor.isNull()
 
-	def openSourceFile(self, fileToOpen):
+	def openSourceFile(self, linkPath):
 		"""Finds and opens the source file for link target fileToOpen.
 
 		When links like [test](test) are clicked, the file test.md is opened.
 		It has to be located next to the current opened file.
 		Relative paths like [test](../test) or [test](folder/test) are also possible.
 		"""
-		if self.fileName:
-			currentExt = splitext(self.fileName)[1]
-			basename, ext = splitext(fileToOpen)
-			if ext in ('.html', '') and exists(basename + currentExt):
-				self.p.openFileWrapper(basename + currentExt)
-				return basename + currentExt
+
+		fileToOpen = self.resolveSourceFile(linkPath)
 		if exists(fileToOpen) and get_markup_for_file_name(fileToOpen, return_class=True):
 			self.p.openFileWrapper(fileToOpen)
 			return fileToOpen
+		if get_markup_for_file_name(fileToOpen, return_class=True):
+			if not QFile.exists(fileToOpen) and QFileInfo(fileToOpen).dir().exists():
+				if self.promptFileCreation(fileToOpen):
+					self.p.openFileWrapper(fileToOpen)
+					return fileToOpen
+
+	def promptFileCreation(self, fileToCreate):
+		"""
+		Prompt user if a file should be created for the clicked link,
+		and try to create it. Return True on success.
+		"""
+		buttonReply = QMessageBox.question(self, self.tr('Create missing file?'),
+		                                   self.tr("The file '%s' does not exist.\n\nDo you want to create it?") % fileToCreate,
+		                                   QMessageBox.StandardButton.Yes | QMessageBox.StandardButton.No,
+		                                   QMessageBox.StandardButton.No)
+		if buttonReply == QMessageBox.StandardButton.Yes:
+			return self.createFile(fileToCreate)
+		elif buttonReply == QMessageBox.StandardButton.No:
+			return False
+
+	def resolveSourceFile(self, linkPath):
+		"""
+		Finds the actual path of the file to open in a new tab.
+		When the link has no extension, eg: [Test](test), the extension of the current file is assumed
+		(eg test.md for a markdown file).
+		When the link is an html file eg: [Test](test.html), the extension of the current file is assumed
+		(eg test.md for a markdown file).
+		Relative paths like [test](../test) or [test](folder/test) are also possible.
+		"""
+		basename, ext = splitext(linkPath)
+		if self.fileName:
+			currentExt = splitext(self.fileName)[1]
+			if ext in ('.html', '') and (exists(basename+currentExt) or not exists(linkPath)):
+				ext = currentExt
+
+		return basename+ext
+
+	def createFile(self, fileToCreate):
+		"""Try to create file, return True if successful"""
+		try:
+			# Create file:
+			open(fileToCreate, 'x').close()
+			return True
+		except OSError as err:
+			QMessageBox.warning(self, self.tr("File could not be created"),
+			                    self.tr("Could not create file '%s': %s") % (fileToCreate, err))
+			return False
