@@ -2,111 +2,91 @@
 <!DOCTYPE TS><TS version="2.0" language="sk_SK" sourcelanguage="en_US">
 <context>
     <name>ConfigDialog</name>
+    <message>
+        <location filename="../ReText/config.py" line="91"/>
+        <source>Using configuration file at:</source>
+        <translation>Súbor s nastaveniami:</translation>
+    </message>
     <message>
         <location filename="../ReText/config.py" line="109"/>
         <source>Behavior</source>
-        <translation type="unfinished"></translation>
+        <translation>Správanie</translation>
     </message>
     <message>
         <location filename="../ReText/config.py" line="109"/>
         <source>Automatically save documents</source>
-        <translation type="unfinished"></translation>
+        <translation>Automaticky ukladať dokumenty</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="109"/>
+        <source>Automatically open last documents on startup</source>
+        <translation>Pri spustení automaticky otvoriť posledné dokumenty</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="109"/>
+        <source>Number of recent documents</source>
+        <translation>Počet posledných dokumentov</translation>
     </message>
     <message>
         <location filename="../ReText/config.py" line="109"/>
         <source>Restore window geometry</source>
-        <translation type="unfinished"></translation>
+        <translation>Obnoviť umiestnenie okna</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="109"/>
+        <source>Default preview state</source>
+        <translation>Predvolený náhľad</translation>
     </message>
     <message>
         <location filename="../ReText/config.py" line="109"/>
         <source>Open external links in ReText window</source>
+        <translation>Otvárať externé odkazy v okne ReText-u</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="109"/>
+        <source>Markdown syntax extensions (comma-separated)</source>
+        <translation>Rozšírenia syntaxe markdown (čiarkou oddelené)</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="109"/>
+        <source>Enable synchronized scrolling for Markdown</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../ReText/config.py" line="184"/>
         <source>Editor</source>
-        <translation type="unfinished"></translation>
+        <translation>Editor</translation>
     </message>
     <message>
         <location filename="../ReText/config.py" line="109"/>
         <source>Highlight current line</source>
-        <translation type="unfinished"></translation>
+        <translation>Zvýrazniť aktuálny riadok</translation>
     </message>
     <message>
         <location filename="../ReText/config.py" line="109"/>
         <source>Show line numbers</source>
-        <translation type="unfinished"></translation>
+        <translation>Zobraziť čísla riadkov</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="109"/>
+        <source>Line numbers are relative to current line</source>
+        <translation>Číslovanie riadkov začne na aktuálnom riadku</translation>
     </message>
     <message>
         <location filename="../ReText/config.py" line="109"/>
         <source>Tab key inserts spaces</source>
-        <translation type="unfinished"></translation>
+        <translation>Kláves Tab vkladá medzery</translation>
     </message>
     <message>
         <location filename="../ReText/config.py" line="109"/>
         <source>Tabulation width</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../ReText/config.py" line="109"/>
-        <source>Interface</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/config.py" line="109"/>
-        <source>Icon theme name</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/config.py" line="109"/>
-        <source>Stylesheet file</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/config.py" line="109"/>
-        <source>Markdown syntax extensions (comma-separated)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/config.py" line="166"/>
-        <source>Help</source>
-        <translation type="unfinished">Pomocník</translation>
-    </message>
-    <message>
-        <location filename="../ReText/config.py" line="109"/>
-        <source>Enable synchronized scrolling for Markdown</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../ReText/config.py" line="109"/>
         <source>Draw vertical line at column</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../ReText/config.py" line="109"/>
-        <source>Automatically open last documents on startup</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/config.py" line="91"/>
-        <source>Using configuration file at:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/config.py" line="109"/>
-        <source>Number of recent documents</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/config.py" line="109"/>
-        <source>Default preview state</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/config.py" line="109"/>
-        <source>Line numbers are relative to current line</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../ReText/config.py" line="109"/>
         <source>Enable soft wrap</source>
@@ -115,12 +95,32 @@
     <message>
         <location filename="../ReText/config.py" line="109"/>
         <source>Show document stats</source>
-        <translation type="unfinished"></translation>
+        <translation>Zobraziť štatistiku dokumentu</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="109"/>
+        <source>Ordered list mode</source>
+        <translation>Režim zoradeného zoznamu</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="109"/>
+        <source>Interface</source>
+        <translation>Rozhranie</translation>
     </message>
     <message>
         <location filename="../ReText/config.py" line="109"/>
         <source>Hide toolbar</source>
-        <translation type="unfinished"></translation>
+        <translation>Skryť panel nástrojov</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="109"/>
+        <source>Icon theme name</source>
+        <translation>Názov motívu ikon</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="109"/>
+        <source>Stylesheet file</source>
+        <translation>Súbor so štýlom</translation>
     </message>
     <message>
         <location filename="../ReText/config.py" line="109"/>
@@ -132,35 +132,35 @@
         <source>Show full path in window title</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../ReText/config.py" line="185"/>
-        <source>Live preview</source>
-        <translation type="unfinished">Priebežný náhľad</translation>
-    </message>
-    <message>
-        <location filename="../ReText/config.py" line="186"/>
-        <source>Normal preview</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/config.py" line="109"/>
-        <source>Ordered list mode</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../ReText/config.py" line="109"/>
         <source>Show directory tree</source>
-        <translation type="unfinished"></translation>
+        <translation>Zobraziť adresárový strom</translation>
     </message>
     <message>
         <location filename="../ReText/config.py" line="109"/>
         <source>Working directory</source>
-        <translation type="unfinished"></translation>
+        <translation>Pracovný adresár</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="166"/>
+        <source>Help</source>
+        <translation>Pomocník</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="185"/>
+        <source>Live preview</source>
+        <translation>Priebežný náhľad</translation>
+    </message>
+    <message>
+        <location filename="../ReText/config.py" line="186"/>
+        <source>Normal preview</source>
+        <translation>Normálny náhľad</translation>
     </message>
     <message>
         <location filename="../ReText/config.py" line="191"/>
         <source>Disabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Vypnuté</translation>
     </message>
     <message>
         <location filename="../ReText/config.py" line="192"/>
@@ -175,12 +175,12 @@
     <message>
         <location filename="../ReText/config.py" line="198"/>
         <source>Increment</source>
-        <translation type="unfinished"></translation>
+        <translation>Prírastok</translation>
     </message>
     <message>
         <location filename="../ReText/config.py" line="199"/>
         <source>Repeat</source>
-        <translation type="unfinished"></translation>
+        <translation>Opakovať</translation>
     </message>
 </context>
 <context>
@@ -188,7 +188,7 @@
     <message>
         <location filename="../ReText/config.py" line="60"/>
         <source>Select directory to open</source>
-        <translation type="unfinished"></translation>
+        <translation>Vyberte adresár na otvorenie</translation>
     </message>
 </context>
 <context>
@@ -196,7 +196,7 @@
     <message>
         <location filename="../ReText/config.py" line="35"/>
         <source>(none)</source>
-        <translation type="unfinished"></translation>
+        <translation>(žiadny)</translation>
     </message>
 </context>
 <context>
@@ -204,7 +204,7 @@
     <message>
         <location filename="../ReText/config.py" line="52"/>
         <source>Select file to open</source>
-        <translation type="unfinished"></translation>
+        <translation>Vyberte súbor na otvorenie</translation>
     </message>
 </context>
 <context>
@@ -212,17 +212,17 @@
     <message>
         <location filename="../ReText/tabledialog.py" line="27"/>
         <source>Insert table</source>
-        <translation type="unfinished"></translation>
+        <translation>Vložiť tabuľku</translation>
     </message>
     <message>
         <location filename="../ReText/tabledialog.py" line="36"/>
         <source>Number of rows</source>
-        <translation type="unfinished"></translation>
+        <translation>Počet riadkov</translation>
     </message>
     <message>
         <location filename="../ReText/tabledialog.py" line="37"/>
         <source>Number of columns</source>
-        <translation type="unfinished"></translation>
+        <translation>Počet stĺpcov</translation>
     </message>
 </context>
 <context>
@@ -230,12 +230,12 @@
     <message>
         <location filename="../ReText/dialogs.py" line="44"/>
         <source>Enter locale name (example: en_US)</source>
-        <translation type="unfinished"></translation>
+        <translation>Zadajte názov lokalizácie (napr.: sk_SK)</translation>
     </message>
     <message>
         <location filename="../ReText/dialogs.py" line="50"/>
         <source>Set as default</source>
-        <translation type="unfinished"></translation>
+        <translation>Nastaviť ako predvolené</translation>
     </message>
 </context>
 <context>
@@ -248,25 +248,25 @@
     <message>
         <location filename="../ReText/fakevimeditor.py" line="118"/>
         <source>Information</source>
-        <translation type="unfinished"></translation>
+        <translation>Informácie</translation>
     </message>
 </context>
 <context>
     <name>ReTextEdit</name>
+    <message>
+        <location filename="../ReText/editor.py" line="248"/>
+        <source>Add to dictionary</source>
+        <translation>Pridať do slovníku</translation>
+    </message>
     <message>
         <location filename="../ReText/editor.py" line="460"/>
         <source>Save image</source>
-        <translation type="unfinished"></translation>
+        <translation>Uložiť obrázok</translation>
     </message>
     <message>
         <location filename="../ReText/editor.py" line="460"/>
         <source>Images (*.png *.jpg)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/editor.py" line="248"/>
-        <source>Add to dictionary</source>
-        <translation type="unfinished"></translation>
+        <translation>Obrázky (*.png *.jpg)</translation>
     </message>
 </context>
 <context>
@@ -284,7 +284,7 @@
     <message>
         <location filename="../ReText/tab.py" line="497"/>
         <source>Create missing file?</source>
-        <translation type="unfinished"></translation>
+        <translation>Vytvoriť chýbajúci súbor?</translation>
     </message>
     <message>
         <location filename="../ReText/tab.py" line="497"/>
@@ -296,12 +296,12 @@ Do you want to create it?</source>
     <message>
         <location filename="../ReText/tab.py" line="530"/>
         <source>File could not be created</source>
-        <translation type="unfinished"></translation>
+        <translation>Súbor sa nepodarilo vytvoriť</translation>
     </message>
     <message>
         <location filename="../ReText/tab.py" line="530"/>
         <source>Could not create file &apos;%s&apos;: %s</source>
-        <translation type="unfinished"></translation>
+        <translation>Nepodarilo sa vytvoriť súbor &apos;%s&apos;: %s</translation>
     </message>
 </context>
 <context>
@@ -331,6 +331,16 @@ Do you want to create it?</source>
         <source>Open</source>
         <translation>Otvoriť</translation>
     </message>
+    <message>
+        <location filename="../ReText/window.py" line="106"/>
+        <source>Set encoding</source>
+        <translation>Nastaviť kódovanie</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="1231"/>
+        <source>Reload</source>
+        <translation>Znovu načítať</translation>
+    </message>
     <message>
         <location filename="../ReText/window.py" line="112"/>
         <source>Save</source>
@@ -341,6 +351,21 @@ Do you want to create it?</source>
         <source>Save as</source>
         <translation>Uložiť ako</translation>
     </message>
+    <message>
+        <location filename="../ReText/window.py" line="117"/>
+        <source>Next tab</source>
+        <translation>Ďalšia karta</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="119"/>
+        <source>Previous tab</source>
+        <translation>Predchádzajúca karta</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="121"/>
+        <source>Close tab</source>
+        <translation>Zavrieť kartu</translation>
+    </message>
     <message>
         <location filename="../ReText/window.py" line="123"/>
         <source>Print</source>
@@ -356,11 +381,26 @@ Do you want to create it?</source>
         <source>View HTML code</source>
         <translation>Zobraziť HTML kód</translation>
     </message>
+    <message>
+        <location filename="../ReText/window.py" line="128"/>
+        <source>Change editor font</source>
+        <translation>Zmeniť písmo editora</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="130"/>
+        <source>Change preview font</source>
+        <translation>Zmeniť písmo náhľadu</translation>
+    </message>
     <message>
         <location filename="../ReText/window.py" line="132"/>
         <source>Find text</source>
         <translation>Nájsť text</translation>
     </message>
+    <message>
+        <location filename="../ReText/window.py" line="719"/>
+        <source>Go to line</source>
+        <translation>Prejsť na riadok</translation>
+    </message>
     <message>
         <location filename="../ReText/window.py" line="137"/>
         <source>Preview</source>
@@ -371,11 +411,36 @@ Do you want to create it?</source>
         <source>Live preview</source>
         <translation>Priebežný náhľad</translation>
     </message>
+    <message>
+        <location filename="../ReText/window.py" line="151"/>
+        <source>Insert table</source>
+        <translation>Vložiť tabuľku</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="153"/>
+        <source>Table editing mode</source>
+        <translation>Režim úpravy tabuľky</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="156"/>
+        <source>Insert images by file path</source>
+        <translation>Vložiť obrázky zadaním cesty</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="159"/>
+        <source>FakeVim mode</source>
+        <translation>Režim FakeVim</translation>
+    </message>
     <message>
         <location filename="../ReText/window.py" line="164"/>
         <source>Fullscreen mode</source>
         <translation>Celoobrazovkový režim</translation>
     </message>
+    <message>
+        <location filename="../ReText/window.py" line="671"/>
+        <source>Preferences</source>
+        <translation>Predvoľby</translation>
+    </message>
     <message>
         <location filename="../ReText/window.py" line="174"/>
         <source>Quit</source>
@@ -406,6 +471,21 @@ Do you want to create it?</source>
         <source>Paste</source>
         <translation>Vložiť</translation>
     </message>
+    <message>
+        <location filename="../ReText/window.py" line="187"/>
+        <source>Paste image</source>
+        <translation>Prilepiť obrázok</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="189"/>
+        <source>Move line up</source>
+        <translation>Presunúť riadok vyššie</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="191"/>
+        <source>Move line down</source>
+        <translation>Presunúť riadok nižšie</translation>
+    </message>
     <message>
         <location filename="../ReText/window.py" line="200"/>
         <source>Enable</source>
@@ -421,6 +501,16 @@ Do you want to create it?</source>
         <source>Use WebKit renderer</source>
         <translation>Použiť k vykresľovaniu WebKit</translation>
     </message>
+    <message>
+        <location filename="../ReText/window.py" line="207"/>
+        <source>Use WebEngine (Chromium) renderer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="212"/>
+        <source>Show directory</source>
+        <translation>Zobraziť priečinok</translation>
+    </message>
     <message>
         <location filename="../ReText/window.py" line="213"/>
         <source>Next</source>
@@ -431,11 +521,31 @@ Do you want to create it?</source>
         <source>Previous</source>
         <translation>Predchádzajúci</translation>
     </message>
+    <message>
+        <location filename="../ReText/window.py" line="217"/>
+        <source>Replace</source>
+        <translation>Nahradiť</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="219"/>
+        <source>Replace all</source>
+        <translation>Nahradiť všetko</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="222"/>
+        <source>Close</source>
+        <translation>Zavrieť</translation>
+    </message>
     <message>
         <location filename="../ReText/window.py" line="226"/>
         <source>Get help online</source>
         <translation>Získať online pomoc</translation>
     </message>
+    <message>
+        <location filename="../ReText/window.py" line="227"/>
+        <source>About ReText</source>
+        <translation>O programe ReText</translation>
+    </message>
     <message>
         <location filename="../ReText/window.py" line="230"/>
         <source>About Qt</source>
@@ -456,6 +566,11 @@ Do you want to create it?</source>
         <source>Underline</source>
         <translation>Podčiarknuté</translation>
     </message>
+    <message>
+        <location filename="../ReText/window.py" line="325"/>
+        <source>Formatting</source>
+        <translation>Formátovanie</translation>
+    </message>
     <message>
         <location filename="../ReText/window.py" line="265"/>
         <source>Symbols</source>
@@ -492,15 +607,20 @@ Do you want to create it?</source>
         <translation>Kontrola pravopisu</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="325"/>
-        <source>Formatting</source>
-        <translation>Formátovanie</translation>
+        <location filename="../ReText/window.py" line="322"/>
+        <source>Default markup</source>
+        <translation>Predvolená markup syntax</translation>
     </message>
     <message>
         <location filename="../ReText/window.py" line="372"/>
         <source>Search</source>
         <translation>Vyhľadávanie</translation>
     </message>
+    <message>
+        <location filename="../ReText/window.py" line="375"/>
+        <source>Replace with</source>
+        <translation>Nahradiť</translation>
+    </message>
     <message>
         <location filename="../ReText/window.py" line="377"/>
         <source>Case sensitively</source>
@@ -511,20 +631,20 @@ Do you want to create it?</source>
         <source>New document</source>
         <translation>Nový dokument</translation>
     </message>
+    <message>
+        <location filename="../ReText/window.py" line="719"/>
+        <source>Type the line number</source>
+        <translation>Zadajte číslo riadka</translation>
+    </message>
     <message>
         <location filename="../ReText/window.py" line="755"/>
         <source>Please, save the file somewhere.</source>
         <translation>Uložte prosím niekam súbor.</translation>
     </message>
-    <message>
-        <location filename="../ReText/window.py" line="212"/>
-        <source>Show directory</source>
-        <translation>Zobraziť priečinok</translation>
-    </message>
     <message>
         <location filename="../ReText/window.py" line="871"/>
         <source>Select one or several files to open</source>
-        <translation>Vyberte jeden alebo viac súborov k otvoreniu</translation>
+        <translation>Vyberte jeden alebo viac súborov na otvorenie</translation>
     </message>
     <message>
         <location filename="../ReText/window.py" line="1289"/>
@@ -534,18 +654,34 @@ Do you want to create it?</source>
     <message>
         <location filename="../ReText/window.py" line="1289"/>
         <source>All files (*)</source>
-        <translation>Všetky súbory (*.*)</translation>
+        <translation>Všetky súbory (*)</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="910"/>
+        <source>Select file encoding from the list:</source>
+        <translation>Vyberte kódovanie súboru zo zoznamu:</translation>
     </message>
     <message>
         <location filename="../ReText/window.py" line="933"/>
         <source>Plain text (*.txt)</source>
         <translation>Jednoduchý text (*.txt)</translation>
     </message>
+    <message>
+        <location filename="../ReText/window.py" line="936"/>
+        <source>%s files</source>
+        <comment>Example of final string: Markdown files</comment>
+        <translation>Súbory %s</translation>
+    </message>
     <message>
         <location filename="../ReText/window.py" line="1011"/>
         <source>Save file</source>
         <translation>Uložiť súbor</translation>
     </message>
+    <message>
+        <location filename="../ReText/window.py" line="956"/>
+        <source>Cannot save to file which is open in another tab!</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../ReText/window.py" line="979"/>
         <source>Cannot save to file because it is read-only!</source>
@@ -566,6 +702,11 @@ Do you want to create it?</source>
         <source>HTML files (*.html *.htm)</source>
         <translation>HTML súbory (*.html *.htm)</translation>
     </message>
+    <message>
+        <location filename="../ReText/window.py" line="1034"/>
+        <source>Unrecognized paperSize setting &quot;%s&quot;.</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../ReText/window.py" line="1060"/>
         <source>Export document to PDF</source>
@@ -592,92 +733,19 @@ Do you want to create it?</source>
         <translation>Nepodarilo sa spustiť príkaz:</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1251"/>
-        <source>The document has been modified.
-Do you want to save your changes?</source>
-        <translation>Dokument bol zmenený.
-Chcete uložiť vaše zmeny?</translation>
+        <location filename="../ReText/window.py" line="1172"/>
+        <source>Alt text</source>
+        <translation>Alt text</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1279"/>
-        <source>HTML code</source>
-        <translation>HTML kód</translation>
+        <location filename="../ReText/window.py" line="1173"/>
+        <source>URL</source>
+        <translation>URL adresa</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1307"/>
-        <source>Author: Dmitry Shachnev, 2011</source>
-        <translation>Autor: Dmitry Shachnev, 2011</translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="1307"/>
-        <source>Markdown syntax</source>
-        <translation>Markdown syntax</translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="227"/>
-        <source>About ReText</source>
-        <translation>O ReText</translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="936"/>
-        <source>%s files</source>
-        <comment>Example of final string: Markdown files</comment>
-        <translation>Súbory %s</translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="1307"/>
-        <source>Simple but powerful editor for Markdown and reStructuredText</source>
-        <translation>Jednoduchý a pritom efektívny editor pre Markdown a reStructuredText</translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="1307"/>
-        <source>reStructuredText syntax</source>
-        <translation>reStructuredText syntax</translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="322"/>
-        <source>Default markup</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="671"/>
-        <source>Preferences</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="106"/>
-        <source>Set encoding</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="910"/>
-        <source>Select file encoding from the list:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="1231"/>
-        <source>Reload</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="117"/>
-        <source>Next tab</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="119"/>
-        <source>Previous tab</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="153"/>
-        <source>Table editing mode</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="159"/>
-        <source>FakeVim mode</source>
-        <translation type="unfinished"></translation>
+        <location filename="../ReText/window.py" line="1173"/>
+        <source>Link text</source>
+        <translation>Text odkazu</translation>
     </message>
     <message>
         <location filename="../ReText/window.py" line="1214"/>
@@ -698,14 +766,21 @@ Do you want to reload the file (this will discard all your changes)?
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="128"/>
-        <source>Change editor font</source>
-        <translation type="unfinished"></translation>
+        <location filename="../ReText/window.py" line="1251"/>
+        <source>The document has been modified.
+Do you want to save your changes?</source>
+        <translation>Dokument bol zmenený.
+Chcete uložiť vaše zmeny?</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="130"/>
-        <source>Change preview font</source>
-        <translation type="unfinished"></translation>
+        <location filename="../ReText/window.py" line="1279"/>
+        <source>HTML code</source>
+        <translation>HTML kód</translation>
+    </message>
+    <message>
+        <location filename="../ReText/window.py" line="1289"/>
+        <source>Select one or several images to open</source>
+        <translation>Vyberte jeden alebo viac obrázkov na otvorenie</translation>
     </message>
     <message>
         <location filename="../ReText/window.py" line="1307"/>
@@ -713,99 +788,24 @@ Do you want to reload the file (this will discard all your changes)?
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="222"/>
-        <source>Close</source>
-        <translation type="unfinished"></translation>
+        <location filename="../ReText/window.py" line="1307"/>
+        <source>Simple but powerful editor for Markdown and reStructuredText</source>
+        <translation>Jednoduchý, no efektívny editor pre Markdown a ReStructuredText</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1172"/>
-        <source>Alt text</source>
-        <translation type="unfinished"></translation>
+        <location filename="../ReText/window.py" line="1307"/>
+        <source>Author: Dmitry Shachnev, 2011</source>
+        <translation>Autor: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1173"/>
-        <source>URL</source>
-        <translation type="unfinished"></translation>
+        <location filename="../ReText/window.py" line="1307"/>
+        <source>Markdown syntax</source>
+        <translation>Syntax Markdown</translation>
     </message>
     <message>
-        <location filename="../ReText/window.py" line="1173"/>
-        <source>Link text</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="217"/>
-        <source>Replace</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="219"/>
-        <source>Replace all</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="375"/>
-        <source>Replace with</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="956"/>
-        <source>Cannot save to file which is open in another tab!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="207"/>
-        <source>Use WebEngine (Chromium) renderer</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="121"/>
-        <source>Close tab</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="719"/>
-        <source>Go to line</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="151"/>
-        <source>Insert table</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="156"/>
-        <source>Insert images by file path</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="187"/>
-        <source>Paste image</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="189"/>
-        <source>Move line up</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="191"/>
-        <source>Move line down</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="719"/>
-        <source>Type the line number</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="1034"/>
-        <source>Unrecognized paperSize setting &quot;%s&quot;.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../ReText/window.py" line="1289"/>
-        <source>Select one or several images to open</source>
-        <translation type="unfinished"></translation>
+        <location filename="../ReText/window.py" line="1307"/>
+        <source>reStructuredText syntax</source>
+        <translation>Syntax reStructuredText</translation>
     </message>
 </context>
 <context>
@@ -832,7 +832,7 @@ Do you want to reload the file (this will discard all your changes)?
     <message>
         <location filename="../ReText/__main__.py" line="94"/>
         <source>List of files to open</source>
-        <translation type="unfinished"></translation>
+        <translation>Zoznam súborov na otvorenie</translation>
     </message>
 </context>
 </TS>
